@@ -39,18 +39,18 @@ class Bot:
         self.conn = websocket.create_connection(f'wss://euphoria.io/room/{self.room}/ws')
         self.conn.recv()
         reply = AttrDict(json.loads(self.conn.recv()))
-        self.handle_ping(reply)
+        self._handle_ping(reply)
         reply = AttrDict(json.loads(self.conn.recv()))
         if reply.type == "snapshot-event":
-            self.setNick(self.nick)
+            self.set_nick(self.nick)
         elif reply.type == "bounce-event":
-            self.handle_auth(self.password)
-            self.setNick(self.nick)
+            self._handle_auth(self.password)
+            self.set_nick(self.nick)
         else:
             print(reply)
         print(f'connected to &{self.room}.')
 
-    def sendMsg(self, msgString, parent = None):
+    def send_msg(self, msgString, parent = None):
         if re.search(r"^\[.+,.+\]$", msgString):
             msgString = random.choice(msgString[1:-1].split(","))
         if isinstance(parent, AttrDict):
@@ -93,29 +93,29 @@ class Bot:
         self.conn.close()
         self.connect()
         self.start()
-        self.sendMsg("Restarted", parent = msg)
+        self.send_msg("Restarted", parent = msg)
 
     def simple_start(self):
         try:
             for msgJSON in self.conn:
                 msg = AttrDict(json.loads(msgJSON))
                 if msg.type == 'ping-event':
-                    self.handle_ping(msg)
+                    self._handle_ping(msg)
                 elif msg.type == 'send-event' and msg.data.sender.name != self.nick:
-                    self.handle_message(msg)
+                    self._handle_message(msg)
                 elif msg.type == 'error':
                     print(msg)
                 elif msg.type == 'bounce-event':
-                    self.handle_auth(msg)
+                    self._handle_auth(msg)
                 else:
-                    self.handle_other(msg)
+                    self._handle_other(msg)
         except KilledError:
             pass
 
     def nothing(msg):
         return
 
-    def is_privileged(self, user):
+    def _is_privileged(self, user):
         if "is_manager" in user.keys() or user.name == self.owner:
             return True
         else:
@@ -148,7 +148,7 @@ class Bot:
                     msg = AttrDict(json.loads(msgJSON))
                     if msg.type == 'send-event' and msg.data.sender.name != self.nick:
                         if re.search(f'^!kill @{self.normname}$', msg.data.content) != None:
-                            self.handle_kill(msg)
+                            self._handle_kill(msg)
                         if re.search(f'^!forcekill @{self.normname}$', msg.data.content) != None:
                             self.kill()
                         if re.search(f'^!restart @{self.normname}$', msg.data.content) != None:
@@ -162,46 +162,46 @@ class Bot:
         else:
             print("Advanced start must be given a callable message handler function that takes an AttrDict as its argument.")
 
-    def handle_ping(self, msg):
+    def _handle_ping(self, msg):
         self.conn.send(json.dumps({'type': 'ping-reply', 'data': {'time': msg.data.time}}))
 
-    def handle_message(self, msg):
+    def _handle_message(self, msg):
         if re.search(f'^!kill @{self.normname}$', msg.data.content) != None:
-            self.handle_kill(msg)
+            self._handle_kill(msg)
         if re.search(f'^!forcekill @{self.normname}$', msg.data.content) != None:
             self.kill()
         if re.search(f'^!restart @{self.normname}$', msg.data.content) != None:
             self.restart()
         if re.search('^!ping$', msg.data.content) != None or re.search(f'^!ping @{self.normname}$', msg.data.content) != None:
-            self.sendMsg(self.ping, parent = msg)
+            self.send_msg(self.ping, parent = msg)
         if re.search(f'^!help @{self.normname}$', msg.data.content) != None:
-            self.sendMsg(self.help, parent = msg)
+            self.send_msg(self.help, parent = msg)
         for regex, response in self._regexes.items():
             if re.search(regex, msg.data.content) != None:
                 if callable(response):
-                    result = response(self, msg)
+                    result = response(self, msg, re.search(regex, msg.data.content))
                     if type(result) == str:
-                        self.sendMsg(result, parent = msg)
+                        self.send_msg(result, parent = msg)
                     elif type(result) == dict:
                         for send, nick in result.items():
-                            self.setNick(nick)
-                            self.sendMsg(send, parent = msg)
-                        self.setNick(self.nick)
+                            self.set_nick(nick)
+                            self.send_msg(send, parent = msg)
+                        self.set_nick(self.nick)
                     elif type(result) == list:
                         for send in result:
-                            self.sendMsg(send, parent = msg)
+                            self.send_msg(send, parent = msg)
                 else:
-                    self.sendMsg(response, parent = msg)
+                    self.send_msg(response, parent = msg)
                 break
 
-    def handle_kill(self, msg):
-        if self.is_privileged(msg.data.sender) or not self.important:
-            self.sendMsg(self.killed, msg)
+    def _handle_kill(self, msg):
+        if self._is_privileged(msg.data.sender) or not self.important:
+            self.send_msg(self.killed, msg)
             self.kill()
         else:
-            self.sendMsg(f"Bot not killed because you are not a host or @{self.normowner}, and this bot is marked as important.\nFor emergencies, use !forcekill.", parent = msg)
+            self.send_msg(f"Bot not killed because you are not a host or @{self.normowner}, and this bot is marked as important.\nFor emergencies, use !forcekill.", parent = msg)
 
-    def handle_auth(self, pw):
+    def _handle_auth(self, pw):
         self.conn.send(json.dumps({'type': 'auth', 'data': {'type': 'passcode', 'passcode': pw}}))
         reply = None
         i = 0
@@ -214,18 +214,18 @@ class Bot:
                     print(f'Successfully logged into {self.room}.')
                 else:
                     print(f'Login unsuccessful. Reason: {reply.data.reason}')
-                    self.handle_auth(getpass("Enter the correct password: "))
+                    self._handle_auth(getpass("Enter the correct password: "))
                 break
             if i > self.API_timeout:
                 print("Auth Error: auth-reply API response not recorded.")
                 break
 
-    def handle_other(self, msg):
+    def _handle_other(self, msg):
         if msg.type in self.handlers.keys():
             self.handlers[msg.type](msg)
 
 
-    def setNick(self, nick):
+    def set_nick(self, nick):
         self.conn.send(json.dumps({'type': 'nick', 'data': {'name': nick}}))
 
     def kill(self):
